import { useState, useEffect, createElement, useCallback } from 'react';

function Blikvanger({ className, rect }) {
    const [visibleRect, setVisibleRect] = useState();
    useEffect(() => {
        if (rect) {
            setVisibleRect(rect);
        }
    }, [rect, setVisibleRect]);
    return (createElement("div", { className: className, style: visibleRect ? {
            top: visibleRect.top + window.scrollY,
            left: visibleRect.left + window.scrollX,
            width: visibleRect.width,
            height: visibleRect.height
        } : {}, "aria-hidden": true, "data-visible": !!rect, onTransitionEnd: (e) => !rect && e.propertyName === 'opacity' && setVisibleRect(undefined) }));
}

function Blik({ className }) {
    const [rect, setRect] = useState();
    const onFocus = useCallback((e) => {
        if (!(e.target instanceof HTMLElement)) {
            return;
        }
        setRect(e.target.getBoundingClientRect());
    }, [setRect]);
    const onBlur = useCallback((e) => {
        if (e instanceof MouseEvent && e.target === document.activeElement) {
            return;
        }
        setRect(undefined);
    }, [setRect]);
    const onResize = useCallback(() => requestAnimationFrame(() => {
        const current = document.activeElement;
        if (!current) {
            return;
        }
        setRect(current.getBoundingClientRect());
    }), [setRect]);
    useEffect(() => {
        document.addEventListener('focusin', onFocus);
        document.addEventListener('mousedown', onBlur);
        window.addEventListener('blur', onBlur);
        window.addEventListener('resize', onResize);
        return () => {
            document.removeEventListener('focusin', onFocus);
            document.removeEventListener('mousedown', onBlur);
            window.removeEventListener('blur', onBlur);
            window.removeEventListener('resize', onResize);
        };
    }, [onFocus, onBlur]);
    return (createElement(Blikvanger, { className: className, rect: rect }));
}

export { Blik };
//# sourceMappingURL=index.es.js.map
